@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .paginator import (
     DescribeGlobalNetworksPaginator,
@@ -96,14 +96,19 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class NetworkManagerClient:
+class NetworkManagerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        NetworkManagerClient exceptions.
+        """
 
     def associate_customer_gateway(
         self, *, CustomerGatewayArn: str, GlobalNetworkId: str, DeviceId: str, LinkId: str = None
@@ -111,7 +116,7 @@ class NetworkManagerClient:
         """
         Associates a customer gateway with a device and optionally, with a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_customer_gateway)
         """
 
@@ -121,7 +126,7 @@ class NetworkManagerClient:
         """
         Associates a link to a device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_link)
         """
 
@@ -137,7 +142,7 @@ class NetworkManagerClient:
         Associates a transit gateway Connect peer with a device, and optionally, with a
         link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_transit_gateway_connect_peer)
         """
 
@@ -145,7 +150,7 @@ class NetworkManagerClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#can_paginate)
         """
 
@@ -163,7 +168,7 @@ class NetworkManagerClient:
         """
         Creates a connection between two devices.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_connection)
         """
 
@@ -184,7 +189,7 @@ class NetworkManagerClient:
         """
         Creates a new device in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.create_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.create_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_device)
         """
 
@@ -194,7 +199,7 @@ class NetworkManagerClient:
         """
         Creates a new, empty global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_global_network)
         """
 
@@ -212,7 +217,7 @@ class NetworkManagerClient:
         """
         Creates a new link for a specified site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.create_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.create_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_link)
         """
 
@@ -227,7 +232,7 @@ class NetworkManagerClient:
         """
         Creates a new site in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.create_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.create_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_site)
         """
 
@@ -237,7 +242,7 @@ class NetworkManagerClient:
         """
         Deletes the specified connection in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_connection)
         """
 
@@ -245,7 +250,7 @@ class NetworkManagerClient:
         """
         Deletes an existing device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_device)
         """
 
@@ -253,7 +258,7 @@ class NetworkManagerClient:
         """
         Deletes an existing global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_global_network)
         """
 
@@ -261,7 +266,7 @@ class NetworkManagerClient:
         """
         Deletes an existing link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_link)
         """
 
@@ -269,7 +274,7 @@ class NetworkManagerClient:
         """
         Deletes an existing site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_site)
         """
 
@@ -279,7 +284,7 @@ class NetworkManagerClient:
         """
         Deregisters a transit gateway from your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#deregister_transit_gateway)
         """
 
@@ -289,7 +294,7 @@ class NetworkManagerClient:
         """
         Describes one or more global networks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#describe_global_networks)
         """
 
@@ -299,7 +304,7 @@ class NetworkManagerClient:
         """
         Disassociates a customer gateway from a device and a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_customer_gateway)
         """
 
@@ -309,7 +314,7 @@ class NetworkManagerClient:
         """
         Disassociates an existing device from a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_link)
         """
 
@@ -319,7 +324,7 @@ class NetworkManagerClient:
         """
         Disassociates a transit gateway Connect peer from a device and link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_transit_gateway_connect_peer)
         """
 
@@ -333,7 +338,7 @@ class NetworkManagerClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#generate_presigned_url)
         """
 
@@ -349,7 +354,7 @@ class NetworkManagerClient:
         """
         Gets information about one or more of your connections in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_connections)
         """
 
@@ -365,7 +370,7 @@ class NetworkManagerClient:
         Gets the association information for customer gateways that are associated with
         devices and links in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_customer_gateway_associations)
         """
 
@@ -381,7 +386,7 @@ class NetworkManagerClient:
         """
         Gets information about one or more of your devices in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_devices)
         """
 
@@ -397,7 +402,7 @@ class NetworkManagerClient:
         """
         Gets the link associations for a device or a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_link_associations)
         """
 
@@ -415,7 +420,7 @@ class NetworkManagerClient:
         """
         Gets information about one or more links in a specified global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.get_links)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.get_links)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_links)
         """
 
@@ -430,7 +435,7 @@ class NetworkManagerClient:
         """
         Gets information about one or more of your sites in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_sites)
         """
 
@@ -446,7 +451,7 @@ class NetworkManagerClient:
         Gets information about one or more of your transit gateway Connect peer
         associations in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_transit_gateway_connect_peer_associations)
         """
 
@@ -462,7 +467,7 @@ class NetworkManagerClient:
         Gets information about the transit gateway registrations in a specified global
         network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_transit_gateway_registrations)
         """
 
@@ -470,7 +475,7 @@ class NetworkManagerClient:
         """
         Lists the tags for a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#list_tags_for_resource)
         """
 
@@ -480,7 +485,7 @@ class NetworkManagerClient:
         """
         Registers a transit gateway in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#register_transit_gateway)
         """
 
@@ -488,7 +493,7 @@ class NetworkManagerClient:
         """
         Tags a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#tag_resource)
         """
 
@@ -496,7 +501,7 @@ class NetworkManagerClient:
         """
         Removes tags from a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#untag_resource)
         """
 
@@ -512,7 +517,7 @@ class NetworkManagerClient:
         """
         Updates the information for an existing connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_connection)
         """
 
@@ -533,7 +538,7 @@ class NetworkManagerClient:
         """
         Updates the details for an existing device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.update_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.update_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_device)
         """
 
@@ -543,7 +548,7 @@ class NetworkManagerClient:
         """
         Updates an existing global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_global_network)
         """
 
@@ -560,7 +565,7 @@ class NetworkManagerClient:
         """
         Updates the details for an existing link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.update_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.update_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_link)
         """
 
@@ -575,7 +580,7 @@ class NetworkManagerClient:
         """
         Updates the information for an existing site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Client.update_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Client.update_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_site)
         """
 
@@ -584,14 +589,14 @@ class NetworkManagerClient:
         self, operation_name: Literal["describe_global_networks"]
     ) -> DescribeGlobalNetworksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_connections"]) -> GetConnectionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
         """
 
@@ -600,14 +605,14 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_customer_gateway_associations"]
     ) -> GetCustomerGatewayAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_devices"]) -> GetDevicesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
         """
 
@@ -616,21 +621,21 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_link_associations"]
     ) -> GetLinkAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_links"]) -> GetLinksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_sites"]) -> GetSitesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
         """
 
@@ -639,7 +644,7 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_transit_gateway_connect_peer_associations"]
     ) -> GetTransitGatewayConnectPeerAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
         """
 
@@ -648,6 +653,6 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_transit_gateway_registrations"]
     ) -> GetTransitGatewayRegistrationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
         """
